package com.miya.fastcashier.util

import com.miya.fastcashier.util.manage.log.FileComparator
import java.io.File
import java.io.FileFilter
import java.text.DecimalFormat
import java.util.*

object FileUtils {
    fun getFileListByDirPath(path: String?, filter: FileFilter?): MutableList<File> {
        val directory = File(path)
        val files = directory.listFiles(filter)
        val result: MutableList<File> = ArrayList()
        if (files == null) {
            return ArrayList()
        }
        for (i in files.indices) {
            result.add(files[i])
        }
        Collections.sort(result, FileComparator())
        return result
    }

    fun cutLastSegmentOfPath(path: String): String {
        return path.substring(0, path.lastIndexOf("/"))
    }

    fun getReadableFileSize(size: Long): String {
        if (size <= 0) return "0"
        val units = arrayOf("B", "KB", "MB", "GB", "TB")
        val digitGroups = (Math.log10(size.toDouble()) / Math.log10(1024.0)).toInt()
        return DecimalFormat("#").format(
            size / Math.pow(
                1024.0,
                digitGroups.toDouble()
            )
        ) + " " + units[digitGroups]
    }

    /**
     * 获取文件长度
     *
     * @param file 文件
     * @return 文件长度
     */
    fun getFileLength(file: File): Long {
        return if (!isFile(file)) -1 else file.length()
    }

    /**
     * 判断是否是文件
     *
     * @param file 文件
     * @return `true`: 是<br></br>`false`: 否
     */
    fun isFile(file: File?): Boolean {
        return file != null && file.exists() && file.isFile
    }

    /**
     * 根据地址获取当前地址下的所有目录和文件，并且排序,同时过滤掉不符合大小要求的文件
     *
     * @param path
     * @return List<File>
    </File> */
    fun getFileList(
        path: String?,
        filter: FileFilter?,
        isGreater: Boolean,
        targetSize: Long
    ): List<File> {
        val list = getFileListByDirPath(path, filter)
        //进行过滤文件大小
        val iterator: MutableIterator<*> = list.iterator()
        while (iterator.hasNext()) {
            val f = iterator.next() as File
            if (f.isFile) {
                //获取当前文件大小
                val size = getFileLength(f)
                if (isGreater) {
                    //当前想要留下大于指定大小的文件，所以过滤掉小于指定大小的文件
                    if (size < targetSize) {
                        iterator.remove()
                    }
                } else {
                    //当前想要留下小于指定大小的文件，所以过滤掉大于指定大小的文件
                    if (size > targetSize) {
                        iterator.remove()
                    }
                }
            }
        }
        return list
    }
}